/**
 * @file
 *
 * @brief tests if compilation works (include and build paths set correct, etc...)
 *
 * @copyright BSD License (see LICENSE.md or https://www.libelektra.org)
 *
 */

#include <gcrypt.h>

int main (void)
{
	gcry_cipher_hd_t elektraCryptoHandle;
	return 0;
}
